@@ -1,6 +1,6 @@
 import requests, os, json, time
-import notion_get_properties as get_prop
-import notion_update_properties as update_prop
+from ftThanos.notion_get_properties import *
+from ftThanos.notion_update_properties import *
 
 class notion_connector:
 	ESC = "\x1b"
@@ -25,9 +25,27 @@ class notion_connector:
 		}
 		self.url = 'https://api.notion.com/v1'
 		self.all_users = (json.loads(requests.get(self.url + '/users', headers=self.head).text))['results']
-		self.update = update_prop.update_properties(users_list=self.all_users)
+		self.update = update_properties(users_list=self.all_users)
 		self.verbose = True
 		print(self.BLUE + "[NOTION CONNECTOR] Verbose activate." + self.DEFAULT)
+		print(self.GREEN + "[NOTION CONNECTOR] Connector ready to use! " + self.BLUE + "(If you need some information : helper() - or thanos@42paris.fr)" + self.DEFAULT)
+
+#############################################
+# Helper présentant les différentes commandes
+#############################################
+	def helper(self):
+		print('[NOTION CONNECTOR] All function available :')
+		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will take the name, else file will be name output.json."))
+		print("\t- \"getDb(dbId)\" -> Activate verbose.")
+		print("\t- \"updateDb(pageId, data)\" -> Activate verbose.")
+		print("\t- \"createDb(parentId)\" -> Activate verbose.")
+		print("\t- \"addPageDb(dbId, name)\" -> Activate verbose.")
+		print("\t- \"getIdLine(elem)\" -> Activate verbose.")
+		print("\t- \"getProperties(elem)\" -> Activate verbose.")
+		print("\t- \"updateProperties(elem)\" -> Activate verbose.")
+		print("\t- \"getAllUsers()\" -> Activate verbose.")
+		print("\t- \"verbose()\" -> Activate verbose.")
+		print("\t- \"unverbose()\" -> Deactivate verbose.")
 
 ###################################
 # Créateur de .json avec de la data
@@ -66,7 +84,7 @@ class notion_connector:
 ###############################
 # Utilisation sur les databases
 ###############################
-	def getDatabase(self, dbId):
+	def getDb(self, dbId):
 		url = self.url + '/databases/' + dbId + '/query'
 		body = {
 			"sorts": [],
@@ -108,7 +126,7 @@ class notion_connector:
 ##################################
 # Créé une nouvelle base de donnée
 ##################################
-	def createDatabase(self, parentId):
+	def createDb(self, parentId):
 		url = self.url + '/blocks/' + parentId + '/children'
 		data = {
 			"children": [
@@ -134,7 +152,7 @@ class notion_connector:
 ############################################################################
 # Rajoute une ligne à la base de donnée, avec pour title le nom mis en param
 ############################################################################
-	def addPageDatabase(self, dbId, name):
+	def addPageDb(self, dbId, name):
 		url = self.url + '/pages'
 		data = {
 			"parent": { "type": "database_id",
@@ -171,7 +189,7 @@ class notion_connector:
 # Récupère la fonction pour avoir un obj de propriété
 #####################################################
 	def getProperties(self, elem):
-		return (get_prop.get_properties()[elem['type']](elem))
+		return (get_properties()[elem['type']](elem))
 
 ##################################################
 # Met à jour une propriété avec les elements voulu
